

## Jupyter Notebook Tutorials

This directory contains some Jupyter notebook tutorials for getting familiar with the
library. We recommend that you walk through them in the following order:

1. `Fields`, `Instances` and `Datasets`.
2. [`Vocabularies`](./vocabulary.ipynb) .
3. The NLP API.
4. `Trainers`, `Models` and `Drivers`
5. Running experiments from JSON with AllenNLP.


To load a tutorial, follow the [install instructions](../../README.md) and then launch Jupyter.

```jupyter notebook```

Jupyter will tell you how to open the website, and from there you can load the tutorial.

Working through these notebooks should provide you with a good understanding of the
way AllenNLP is structured and how you can get the most out of using it. Enjoy!
